==> open-xchange-core_6.22.1.orig.tar.bz2: open-xchange-core-6.22.1/com.openexchange.hazelcast/src/com/openexchange/hazelcast/osgi/HazelcastClusterListener.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2020 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.hazelcast.osgi;

import java.net.InetAddress;
import java.util.Collections;
import org.apache.commons.logging.Log;
import com.openexchange.cluster.discovery.ClusterListener;
import com.openexchange.hazelcast.osgi.HazelcastActivator.InitMode;

/**
 * {@link HazelcastClusterListener}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
final class HazelcastClusterListener implements ClusterListener {

    private final HazelcastActivator activator;
    private final long stamp;
    private final Log logger;

    /**
     * Initializes a new {@link HazelcastClusterListener}.
     */
    protected HazelcastClusterListener(final HazelcastActivator activator, final long stamp, Log logger) {
        super();
        this.activator = activator;
        this.stamp = stamp;
        this.logger = logger;
    }

    @Override
    public void removed(final InetAddress address) {
        final InitMode initMode = activator.remove(Collections.<InetAddress> singletonList(address), logger);
        if (InitMode.RE_INITIALIZED.equals(initMode)) {
            if (logger.isInfoEnabled()) {
                logger.info("\nHazelcast:\n\tRe-Initialized Hazelcast instance via cluster listener notification about a disappeared Open-Xchange node: "+address+"\n");
            }
        }
    }

    @Override
    public void added(final InetAddress address) {
        final InitMode initMode = activator.init(Collections.<InetAddress> singletonList(address), true, stamp, logger);
        if (InitMode.INITIALIZED.equals(initMode)) {
            if (logger.isInfoEnabled()) {
                logger.info("\nHazelcast:\n\tInitialized Hazelcast instance via cluster listener notification about an appeared Open-Xchange node: "+address+"\n");
            }
        } else if (InitMode.RE_INITIALIZED.equals(initMode)) {
            if (logger.isInfoEnabled()) {
                logger.info("\nHazelcast:\n\tRe-Initialized Hazelcast instance via cluster listener notification about an appeared Open-Xchange node: "+address+"\n");
            }
        }
    }

}

==> open-xchange-core_7.0.2.orig.tar.bz2: open-xchange-core-7.0.2/com.openexchange.hazelcast/src/com/openexchange/hazelcast/osgi/HazelcastClusterListener.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2020 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.hazelcast.osgi;

import java.net.InetAddress;
import java.util.Collections;
import org.apache.commons.logging.Log;
import com.openexchange.cluster.discovery.ClusterListener;
import com.openexchange.hazelcast.init.HazelcastInitializer;

/**
 * {@link HazelcastClusterListener}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
final class HazelcastClusterListener implements ClusterListener {

    private final HazelcastInitializer initializer;
    private final long stamp;
    private final Log logger;

    /**
     * Initializes a new {@link HazelcastClusterListener}.
     */
    protected HazelcastClusterListener(final HazelcastInitializer initializer, final long stamp, Log logger) {
        super();
        this.initializer = initializer;
        this.stamp = stamp;
        this.logger = logger;
    }

    @Override
    public void removed(final InetAddress address) {
        final HazelcastInitializer.InitMode initMode = initializer.remove(Collections.<InetAddress> singletonList(address), false, logger);
        if (HazelcastInitializer.InitMode.RE_INITIALIZED == initMode) {
            if (logger.isInfoEnabled()) {
                logger.info("\nHazelcast:\n\tRe-Initialized Hazelcast instance via cluster listener notification about a disappeared Open-Xchange node: "+address+"\n");
            }
        }
    }

    @Override
    public void added(final InetAddress address) {
        final HazelcastInitializer.InitMode initMode = initializer.init(Collections.<InetAddress> singletonList(address), false, stamp, logger);
        if (HazelcastInitializer.InitMode.INITIALIZED == initMode) {
            if (logger.isInfoEnabled()) {
                logger.info("\nHazelcast:\n\tInitialized Hazelcast instance via cluster listener notification about an appeared Open-Xchange node: "+address+"\n");
            }
        } else if (HazelcastInitializer.InitMode.RE_INITIALIZED == initMode) {
            if (logger.isInfoEnabled()) {
                logger.info("\nHazelcast:\n\tRe-Initialized Hazelcast instance via cluster listener notification about an appeared Open-Xchange node: "+address+"\n");
            }
        }
    }

}
